# Generated by Django 3.2.18 on 2023-03-06 15:54

try:
    from django.db.models import JSONField
except ImportError:  # TODO Remove when dropping Django releases < 3.1
    from django.contrib.postgres.fields import JSONField
import django.core.serializers.json
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('geostore', '0046_auto_20211013_1334'),
    ]

    operations = [
        migrations.AlterField(
            model_name='feature',
            name='properties',
            field=JSONField(blank=True, default=dict, encoder=django.core.serializers.json.DjangoJSONEncoder, verbose_name='Properties'),
        ),
    ]
